
TODO_04_84_79_11: reorganize tests for CI

Make it clear:
*   what tests are meant be run in CI (including end-to-end which start local server)
*   what tests are difficult to set up in CI (e.g. `gui_tests`)
*   what tests are questionable to run in CI (e.g. those "online" which actually use Internet to clone remote repos).
*   etc.
